#!/bin/sh


. /lib/functions.sh



make_archiver_entry() {
	local archiver_name=$1
	local path=$2
	local destpath=$3
	local keep=$4


	uci batch <<-EOF                                                                                                 
		set archiver.$archiver_name=archiver
		set archiver.$archiver_name.path='$path'
		set archiver.$archiver_name.keep='$keep'
		set archiver.$archiver_name.destpath='$destpath'
	EOF
}


get_archiver_keep_days() {
	local archiver_section_name=$1
	local default_keep=$2
	local keep_days

	if [ -z "$default_keep" ]; then
		default_keep="14"
	fi
	keep_days=$(uci -q get archiver.$archiver_section_name.keep) || {
		keep_days=$default_keep
	}
 	echo $keep_days	
}

batch_cb() {                                                                    
        local config=$1                                                             
        local archive_root=$2                                                               
        local compute_config=$3                                                               
        local b                                                                     
                                                                                    
        #echo "config: " $1                                                         

	echo "compute config: " $compute_config

        batch="${compute_config}_$config"                                                                                    
        config_get input_json $config input_json                                           
        config_get output_json $config output_json                                          
        
	echo "batch: " $batch
	echo "input json: " $input_json
	echo "output_json: " $output_json


	if [ -n "$input_json" ]; then
		archiver_name="${batch}_input"
		input_json_base_name=$(basename $input_json)
		keep_days=$(get_archiver_keep_days $archiver_name 14)
		dest_path="${archive_root}/${input_json_base_name}"
		make_archiver_entry "$archiver_name" "$input_json" "$dest_path" $keep_days 
#	        uci batch <<-EOF                                                                                                 
#	                set archiver.$archiver_name=archiver
#	                set archiver.$archiver_name.path='$input_json'                                                  
#	                set archiver.$archiver_name.keep='14'                                            
#	                set archiver.$archiver_name.destpath='$dest_path'                                            
#		EOF
	fi
	if [ -n "$output_json" ]; then
		archiver_name="${batch}_output"
		output_json_base_name=$(basename $output_json)
		dest_path="${archive_root}/${output_json_base_name}"
		keep_days=$(get_archiver_keep_days 90)
		make_archiver_entry "$archiver_name" "$output_json" "$dest_path" $keep_days
#	        uci batch <<-EOF                                                                                                 
#	                set archiver.$archiver_name=archiver
#	                set archiver.$archiver_name.path='$output_json'                                                  
#	                set archiver.$archiver_name.keep='14'                                            
#	                set archiver.$archiver_name.destpath='$dest_path'                                            
#		EOF
	fi

}                                                                                   
                                                                          
                                                                          
make_batch_list() {                                                   
	local compute_config=$1

        echo "Make archive entries"
	config_load archiver
	config_get archive_root config path "/opt/novatec/data/archive"

	config_load $compute_config
	pumpsense_archive_root="$archive_root/${compute_config}"
        config_foreach batch_cb processor $pumpsense_archive_root $compute_config 
}                                                                         
                                                                          


make_archiver_entries() {
	local compute_config=$1

	make_batch_list $compute_config
}




